EasyExtend.langlets.p4d.p4dbase.P4DNode

Package EasyExtend :: Package langlets :: Package p4d :: Module p4dbase :: Class P4DNode |
[hide private]
[frames] | no frames]

# Class P4DNode

    object --+
             |
            P4DNode

Used to build list-trees from the bottom up. P4DNode objects might eventually be converted into P4D objects providing a richer interface.

Instance Methods | [hide private]
__init__(self, tag=`'````'`, attrs=`{``}`, text=`'````'`) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
copy(self) |
__getattr__(self, name) |
__getitem__(self, idx) |
_to_list(self) |
__repr__(self) repr(x) |
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, tag=`'````'`, attrs=`{``}`, text=`'````'`) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)